package com.yc.ship.module.resource.controller.admin.guide.vo;

import com.yc.ship.framework.common.pojo.PageParam;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import java.time.LocalDateTime;
import java.util.List;

import static com.yc.ship.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;


@Schema(description = "管理后台 - 导游管理分页 Request VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class GuidePageReqVO extends PageParam {
    @Schema(description = "id", example = "111")
    private String id;

    @Schema(description = "导游名称", example = "王五")
    private String name;

    @Schema(description = "导游编号")
    private String guideCode;

    @Schema(description = "导游证件号")
    private String guideCardCode;

    @Schema(description = "身份证号")
    private String idCard;

    @Schema(description = "性别")
    private Integer sex;

    @Schema(description = "生日")
    private String birthday;

    @Schema(description = "联系电话")
    private String phone;

    @Schema(description = "导游级别(高级、中级、初级、实习)")
    private String techniLevel;

    @Schema(description = "供应商ID（导游提供方表）", example = "2489")
    private String companyId;

    @Schema(description = "导游类型(0内部、1外部)", example = "1")
    private String guideType;

    @Schema(description = "学历(小学、初中、高中、大学、研究生..)", example = "2")
    private Integer eduType;

    @Schema(description = "民族")
    private String nation;

    @Schema(description = "联系地址")
    private String address;

    @Schema(description = "紧急联系电话")
    private String emergentPhone;

    @Schema(description = "语种-多选（中文、英语、法语..）", example = "2")
    private String languageType;

    @Schema(description = "所属分组（导游分组表）")
    private String groupCode;

    @Schema(description = "所属分组及所有下属分组")
    private List<String> groupList;

    @Schema(description = "认证状态：草稿、审核中、已通过、已驳回", example = "1")
    private Integer authStatus;

    @Schema(description = "启用状态：0禁用、1启用", example = "1")
    private Integer useStatus;

    @Schema(description = "导游特长")
    private String guideSpeciality;

    @Schema(description = "导游标签")
    private String guideTag;

    @Schema(description = "导游证件号正面")
    private String guideCardImgUrl1;

    @Schema(description = "导游证件号背面")
    private String guideCardImgUrl2;

    @Schema(description = "身份证证件号正面")
    private String idCardImgUrl1;

    @Schema(description = "身份证证件号背面")
    private String idCardImgUrl2;

    @Schema(description = "开户银行", example = "芋艿")
    private String bankName;

    @Schema(description = "开户账户")
    private String bankUserCode;

    @Schema(description = "银行账户名", example = "张三")
    private String bankUserName;

    @Schema(description = "联行号")
    private String bankUserLink;

    @Schema(description = "创建时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime[] createTime;

}
