package com.yc.ship.module.resource.service.productBase;

import cn.hutool.core.lang.tree.TreeNode;
import com.yc.ship.framework.common.pojo.PageResult;
import com.yc.ship.module.resource.controller.admin.productBase.vo.ProductBasePageReqVO;
import com.yc.ship.module.resource.controller.admin.productBase.vo.ProductBaseRespVO;
import com.yc.ship.module.resource.controller.admin.productBase.vo.ProductBaseSaveReqVO;
import com.yc.ship.module.resource.dal.dataobject.productBase.ProductBaseDO;

import javax.validation.Valid;
import java.util.List;

/**
 * 基础产品 Service 接口
 *
 * @author 管理员
 */
public interface ProductBaseService {

    /**
     * 创建基础产品
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createBase(@Valid ProductBaseSaveReqVO createReqVO);

    /**
     * 更新基础产品
     *
     * @param updateReqVO 更新信息
     */
    void updateBase(@Valid ProductBaseSaveReqVO updateReqVO);

    /**
     * 删除基础产品
     *
     * @param id 编号
     */
    void deleteBase(Long id);

    /**
     * 获得基础产品
     *
     * @param id 编号
     * @return 基础产品
     */
    ProductBaseRespVO getBase(Long id);

    /**
     * 获得基础产品分页
     *
     * @param pageReqVO 分页查询
     * @return 基础产品分页
     */
    PageResult<ProductBaseDO> getBasePage(ProductBasePageReqVO pageReqVO);

    /**
     * 获得基础产品分页
     *
     * @param pageReqVO 分页查询
     * @return 基础产品分页
     */
    PageResult<ProductBaseRespVO> queryBasePage(ProductBasePageReqVO pageReqVO);

    /**
     * 获得基础产品
     *
     * @param pageReqVO 分页查询
     * @return 基础产品
     */
    PageResult<ProductBaseRespVO> selectBasePage(ProductBasePageReqVO pageReqVO);

    /**
     * 获得基础产品
     * @param pageReqVO 查询
     * @return 基础产品
     */
    List<ProductBaseRespVO> selectBaseList(ProductBasePageReqVO pageReqVO);

    List<TreeNode<Long>> getProductBaseTreeList();
}